@@ -12,7 +12,9 @@ class GitSimBranch(GitSimBaseCommand):
         super().__init__(scene)
 
     def execute(self):
-        print("Simulating: git " + self.scene.args.subcommand + " " + self.scene.args.name)
+        print(
+            "Simulating: git " + self.scene.args.subcommand + " " + self.scene.args.name
+        )
 
         self.show_intro()
         self.get_commits()
@@ -20,8 +22,19 @@ class GitSimBranch(GitSimBaseCommand):
         self.recenter_frame()
         self.scale_frame()
 
-        branchText = m.Text(self.scene.args.name, font="Monospace", font_size=20, color=self.scene.fontColor)
-        branchRec = m.Rectangle(color=m.GREEN, fill_color=m.GREEN, fill_opacity=0.25, height=0.4, width=branchText.width+0.25)
+        branchText = m.Text(
+            self.scene.args.name,
+            font="Monospace",
+            font_size=20,
+            color=self.scene.fontColor,
+        )
+        branchRec = m.Rectangle(
+            color=m.GREEN,
+            fill_color=m.GREEN,
+            fill_opacity=0.25,
+            height=0.4,
+            width=branchText.width + 0.25,
+        )
 
         branchRec.next_to(self.topref, m.UP)
         branchText.move_to(branchRec.get_center())
@@ -29,7 +42,7 @@ class GitSimBranch(GitSimBaseCommand):
         fullbranch = m.VGroup(branchRec, branchText)
 
         if self.scene.args.animate:
-            self.scene.play(m.Create(fullbranch), run_time=1/self.scene.args.speed)
+            self.scene.play(m.Create(fullbranch), run_time=1 / self.scene.args.speed)
         else:
             self.scene.add(fullbranch)
 
