@@ -19,12 +19,23 @@ class GitSimRestore(GitSimBaseCommand):
             pass
 
         for name in self.scene.args.name:
-            if name not in [x.a_path for x in self.repo.index.diff(None)] + [y.a_path for y in self.repo.index.diff("HEAD")]:
-                print("git-sim error: No modified or staged file with name: '" + name + "'")
+            if name not in [x.a_path for x in self.repo.index.diff(None)] + [
+                y.a_path for y in self.repo.index.diff("HEAD")
+            ]:
+                print(
+                    "git-sim error: No modified or staged file with name: '"
+                    + name
+                    + "'"
+                )
                 sys.exit()
 
     def execute(self):
-        print("Simulating: git " + self.scene.args.subcommand + " " + " ".join(self.scene.args.name))
+        print(
+            "Simulating: git "
+            + self.scene.args.subcommand
+            + " "
+            + " ".join(self.scene.args.name)
+        )
 
         self.show_intro()
         self.get_commits()
@@ -36,7 +47,14 @@ class GitSimRestore(GitSimBaseCommand):
         self.fadeout()
         self.show_outro()
 
-    def populate_zones(self, firstColumnFileNames, secondColumnFileNames, thirdColumnFileNames, firstColumnArrowMap, secondColumnArrowMap):
+    def populate_zones(
+        self,
+        firstColumnFileNames,
+        secondColumnFileNames,
+        thirdColumnFileNames,
+        firstColumnArrowMap,
+        secondColumnArrowMap,
+    ):
 
         for x in self.repo.index.diff(None):
             if "git-sim_media" not in x.a_path:
@@ -44,7 +62,9 @@ class GitSimRestore(GitSimBaseCommand):
                 for name in self.scene.args.name:
                     if name == x.a_path:
                         thirdColumnFileNames.add(x.a_path)
-                        secondColumnArrowMap[x.a_path] = m.Arrow(stroke_width=3, color=self.scene.fontColor)
+                        secondColumnArrowMap[x.a_path] = m.Arrow(
+                            stroke_width=3, color=self.scene.fontColor
+                        )
 
         for y in self.repo.index.diff("HEAD"):
             if "git-sim_media" not in y.a_path:
@@ -52,4 +72,6 @@ class GitSimRestore(GitSimBaseCommand):
                 for name in self.scene.args.name:
                     if name == y.a_path:
                         secondColumnFileNames.add(y.a_path)
-                        firstColumnArrowMap[y.a_path] = m.Arrow(stroke_width=3, color=self.scene.fontColor)
+                        firstColumnArrowMap[y.a_path] = m.Arrow(
+                            stroke_width=3, color=self.scene.fontColor
+                        )
